## Learn

`Distilabel` since version `1.0.0` works with a new concept of `Pipeline` made of `Steps`.
These steps can be thought of as `Nodes` in a graph (a `Pipeline` in `distilabel` is mapped internally to a `Directed Acyclic Graph (DAG)`), and can be freely combined to generate synthetic and AI feedback datasets.

This guide can be considered a tutorial, which will guide through the different components of `distilabel`.
